You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by ma...@apache.org on 2015/02/21 17:25:45 UTC

svn commit: r1661388 - /tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java

Author: markt
Date: Sat Feb 21 16:25:45 2015
New Revision: 1661388

URL: http://svn.apache.org/r1661388
Log:
For future reference, add the OpenSSL constant names to aid selecting the write values when adding new Ciphers.

Modified:
    tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java

Modified: tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java
URL: http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java?rev=1661388&r1=1661387&r2=1661388&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java (original)
+++ tomcat/trunk/java/org/apache/tomcat/util/net/jsse/openssl/KeyExchange.java Sat Feb 21 16:25:45 2015
@@ -18,16 +18,16 @@
 package org.apache.tomcat.util.net.jsse.openssl;
 
 enum KeyExchange {
-    EECDH /* ephemeral ECDH */,
-    RSA /* RSA key exchange */,
-    DHr /* DH cert, RSA CA cert */ /* no such ciphersuites supported! */,
-    DHd /* DH cert, DSA CA cert */ /* no such ciphersuite supported! */,
-    EDH /* tmp DH key no DH cert */,
-    PSK /* PSK */,
-    FZA /* Fortezza */  /* no such ciphersuite supported! */,
-    KRB5 /* Kerberos 5 key exchange */,
-    ECDHr /* ECDH cert, RSA CA cert */,
-    ECDHe /* ECDH cert, ECDSA CA cert */,
-    GOST /* GOST key exchange */,
-    SRP /* SRP */;
+    EECDH /* SSL_kECDHE - ephemeral ECDH */,
+    RSA   /* SSL_kRSA   - RSA key exchange */,
+    DHr   /* SSL_kDHr   - DH cert, RSA CA cert */ /* no such ciphersuites supported! */,
+    DHd   /* SSL_kDHd   - DH cert, DSA CA cert */ /* no such ciphersuite supported! */,
+    EDH   /* SSL_kDHE   - tmp DH key no DH cert */,
+    PSK   /* SSK_kPSK   - PSK */,
+    FZA   /* SSL_kFZA   - Fortezza */  /* no such ciphersuite supported! */,
+    KRB5  /* SSL_kKRB5  - Kerberos 5 key exchange */,
+    ECDHr /* SSL_kECDHr - ECDH cert, RSA CA cert */,
+    ECDHe /* SSL_eECDHe - ECDH cert, ECDSA CA cert */,
+    GOST  /* SSL_kGOST  - GOST key exchange */,
+    SRP   /* SSL_kSRP   - SRP */;
 }



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org